@@ -18,6 +18,7 @@ import tempfile
 
 import apport.fileutils
 import apport.logging
+import apport.report
 from apport.packaging_impl import impl as packaging
 
 
@@ -31,16 +32,14 @@ def needed_packages(report):
 
     # first, grab the versions that we captured at crash time
     for line in (
-        report.get("Package", "") + "\n" + report.get("Dependencies", "")
+        f"{report.get('Package', '')}\n{report.get('Dependencies', '')}"
     ).splitlines():
         if not line.strip():
             continue
         try:
             (pkg, version) = line.split()[:2]
         except ValueError:
-            apport.logging.warning(
-                "invalid Package/Dependencies line: %s", line
-            )
+            apport.logging.warning("invalid Package/Dependencies line: %s", line)
             # invalid line, ignore
             continue
         pkgs[pkg] = version
@@ -52,16 +51,14 @@ def report_package_versions(report):
     """Return package -> version dictionary from report."""
     pkg_vers = {}
     for line in (
-        report.get("Package", "") + "\n" + report.get("Dependencies", "")
+        f"{report.get('Package', '')}\n{report.get('Dependencies', '')}"
     ).splitlines():
         if not line.strip():
             continue
         try:
             (pkg, version) = line.split()[:2]
         except ValueError:
-            apport.logging.warning(
-                "invalid Package/Dependencies line: %s", line
-            )
+            apport.logging.warning("invalid Package/Dependencies line: %s", line)
             # invalid line, ignore
             continue
         pkg_vers[pkg] = version
@@ -69,9 +66,7 @@ def report_package_versions(report):
     return pkg_vers
 
 
-def needed_runtime_packages(
-    report, pkgmap_cache_dir, pkg_versions, verbose=False
-):
+def needed_runtime_packages(report, pkgmap_cache_dir, pkg_versions, verbose=False):
     """Determine necessary runtime packages for given report.
 
     This determines libraries dynamically loaded at runtime in two cases:
@@ -94,14 +89,12 @@ def needed_runtime_packages(
             if not line.strip():
                 continue
             cols = line.split()
-            if len(cols) in (6, 7) and "x" in cols[1] and ".so" in cols[5]:
+            if len(cols) in {6, 7} and "x" in cols[1] and ".so" in cols[5]:
                 lib = os.path.realpath(cols[5])
                 libs.add(lib)
     else:
         # 'ProcMaps' key is absent in apport-valgrind use case
-        libs = apport.fileutils.shared_libraries(
-            report["ExecutablePath"]
-        ).values()
+        libs = apport.fileutils.shared_libraries(report["ExecutablePath"]).values()
     if not os.path.exists(pkgmap_cache_dir):
         os.makedirs(pkgmap_cache_dir)
 
@@ -117,8 +110,7 @@ def needed_runtime_packages(
         if pkg:
             if verbose:
                 apport.logging.log(
-                    "dynamically loaded %s needs package %s, queueing"
-                    % (line, pkg)
+                    f"dynamically loaded {line} needs package {pkg}, queueing"
                 )
             pkgs.add(pkg)
         else:
@@ -129,16 +121,28 @@ def needed_runtime_packages(
     return [(p, pkg_versions.get(p)) for p in pkgs]
 
 
+def _move_base_files_first(pkgs: list[tuple[str, None | str]]) -> None:
+    """Move base-files to the front or add it if missing."""
+    for i, (pkg, version) in enumerate(pkgs):
+        if pkg == "base-files":
+            pkgs.pop(i)
+            pkgs[:0] = [("base-files", version)]
+            return
+
+
+# pylint: disable-next=too-many-arguments,too-many-positional-arguments
 def make_sandbox(
-    report,
-    config_dir,
-    cache_dir=None,
-    sandbox_dir=None,
-    extra_packages=None,
-    verbose=False,
-    log_timestamps=False,
-    dynamic_origins=False,
-):
+    report: apport.report.Report,
+    config_dir: str | None,
+    cache_dir: str | None = None,
+    sandbox_dir: str | None = None,
+    extra_packages: list[str] | None = None,
+    verbose: bool = False,
+    log_timestamps: bool = False,
+    dynamic_origins: bool = False,
+) -> tuple[str, str, str]:
+    # TODO: Split into smaller functions/methods
+    # pylint: disable=too-complex,too-many-branches,too-many-locals,too-many-statements
     """Build a sandbox with the packages that belong to a particular report.
 
     This downloads and unpacks all packages from the report's Package and
@@ -147,10 +151,10 @@ def make_sandbox(
     some extra ones, for the distro release and architecture of the report.
 
     For unpackaged executables, there are no Dependencies. Packages for shared
-    libaries are unpacked.
+    libraries are unpacked.
 
-    report is an apport.Report object to build a sandbox for. Presence of the
-    Package field determines whether to determine dependencies through
+    report is an apport.report.Report object to build a sandbox for. Presence
+    of the Package field determines whether to determine dependencies through
     packaging (via the optional report['Dependencies'] field), or through ldd
     via needed_runtime_packages() -> shared_libraries().  Usually
     report['Architecture'] and report['Uname'] are present.
@@ -222,13 +226,14 @@ def make_sandbox(
 
     origins = None
     if dynamic_origins:
-        pkg_list = (
-            report.get("Package", "") + "\n" + report.get("Dependencies", "")
-        )
-        m = re.compile(r"\[origin: ([a-zA-Z0-9][a-zA-Z0-9\+\.\-]+)\]")
-        origins = set(m.findall(pkg_list))
+        pkg_list = f"{report.get('Package', '')}\n{report.get('Dependencies', '')}"
+        match = re.compile(r"\[origin: ([a-zA-Z0-9][a-zA-Z0-9\+\.\-]+)\]")
+        origins = set(match.findall(pkg_list))
         if origins:
-            apport.logging.log("Origins: %s" % origins)
+            apport.logging.log(f"Origins: {origins}")
+
+    # Install base-files first to get correct usrmerge
+    _move_base_files_first(pkgs)
 
     # unpack packages, if any, using cache and sandbox
     try:
@@ -244,7 +249,7 @@ def make_sandbox(
             origins=origins,
         )
     except SystemError as error:
-        apport.logging.fatal(str(error))
+        apport.logging.fatal("%s", str(error))
 
     # install the extra packages and their deps
     if extra_packages:
@@ -263,12 +268,10 @@ def make_sandbox(
                 install_deps=True,
             )
         except SystemError as error:
-            apport.logging.fatal(str(error))
+            apport.logging.fatal("%s", str(error))
 
     pkg_versions = report_package_versions(report)
-    pkgs = needed_runtime_packages(
-        report, pkgmap_cache_dir, pkg_versions, verbose
-    )
+    pkgs = needed_runtime_packages(report, pkgmap_cache_dir, pkg_versions, verbose)
 
     # package hooks might reassign Package:, check that we have the originally
     # crashing binary
@@ -291,8 +294,7 @@ def make_sandbox(
                     pkg = "systemd"
             if pkg:
                 apport.logging.log(
-                    "Installing extra package %s to get %s" % (pkg, path),
-                    log_timestamps,
+                    f"Installing extra package {pkg} to get {path}", log_timestamps
                 )
                 pkgs.append((pkg, pkg_versions.get(pkg)))
             else:
@@ -315,24 +317,21 @@ def make_sandbox(
                 origins=origins,
             )
         except SystemError as error:
-            apport.logging.fatal(str(error))
+            apport.logging.fatal("%s", str(error))
 
-    # sanity check: for a packaged binary we require having the executable in
-    # the sandbox; TODO: for an unpackage binary we don't currently copy its
+    # consistency check: for a packaged binary we require having the executable
+    # in the sandbox; TODO: for an unpackage binary we don't currently copy its
     # potential local library dependencies (like those in build trees) into the
     # sandbox, and we call gdb/valgrind on the binary outside the sandbox.
     if "Package" in report:
         for path in ("InterpreterPath", "ExecutablePath"):
-            if path in report and not os.path.exists(
-                sandbox_dir + report[path]
-            ):
+            if path in report and not os.path.exists(sandbox_dir + report[path]):
                 if report[path].startswith("/usr"):
                     if os.path.exists(sandbox_dir + report[path][4:]):
                         report[path] = report[path][4:]
                     else:
                         apport.logging.fatal(
-                            "%s %s does not exist"
-                            " (report specified package %s)",
+                            "%s %s does not exist (report specified package %s)",
                             path,
                             sandbox_dir + report[path],
                             report["Package"],
