@@ -84,7 +84,7 @@ def query_data_api_once(api_address, timeout, requests_session):
             session=requests_session,
             # If the error is a HTTP/404 or a ConnectionError, go into raise
             # block below and don't bother retrying.
-            exception_cb=lambda _, exc: exc.code != 404
+            exception_cb=lambda exc: exc.code != 404
             and (
                 not isinstance(exc.cause, requests.exceptions.ConnectionError)
             ),
@@ -235,7 +235,7 @@ class DataSourceScaleway(sources.DataSource):
         )
 
     @staticmethod
-    def ds_detect():
+    def ds_detect() -> bool:
         """
         There are three ways to detect if you are on Scaleway:
 
@@ -254,6 +254,7 @@ class DataSourceScaleway(sources.DataSource):
         cmdline = util.get_cmdline()
         if "scaleway" in cmdline:
             return True
+        return False
 
     def _get_data(self):
 
