@@ -6,14 +6,14 @@ See https://github.com/python-jsonschema/jsonschema/pull/232.
 from pathlib import Path
 
 from pyperf import Runner
-from pyrsistent import m
+from referencing import Registry
 
 from jsonschema.tests._suite import Version
 import jsonschema
 
 issue232 = Version(
     path=Path(__file__).parent / "issue232",
-    remotes=m(),
+    remotes=Registry(),
     name="issue232",
 )
 
